@@ -167,12 +167,13 @@ CK_RV CPKCS11Lib::C_GetTokenInfo (
 
 CK_RV CPKCS11Lib::C_InitToken(
 	CK_SLOT_ID slotID,
-	char* pPin,
-	CK_ULONG ulPinLen,
+	vector<unsigned char> pin,
 	const char* pLabel)
 {
 	CPKCS11LIB_PROLOGUE(C_InitToken);
-	rv = m_pFunc->C_InitToken(slotID, (CK_CHAR*)pPin, ulPinLen,
+	CK_ULONG ulPinLen = 0;
+	CK_BYTE* pPin = Vector2Buffer(pin, ulPinLen);
+	rv = m_pFunc->C_InitToken(slotID, (CK_UTF8CHAR_PTR) pPin, ulPinLen,
 		(CK_CHAR*)pLabel);
 	CPKCS11LIB_EPILOGUE;
 	return rv;
@@ -180,10 +181,11 @@ CK_RV CPKCS11Lib::C_InitToken(
 
 CK_RV CPKCS11Lib::C_InitPIN(
 	CK_SESSION_HANDLE hSession,
-	char* pPin,
-	CK_ULONG ulPinLen)
+	vector<unsigned char> pin)
 {
 	CPKCS11LIB_PROLOGUE(C_InitPIN);
+	CK_ULONG ulPinLen = 0;
+	CK_BYTE* pPin = Vector2Buffer(pin, ulPinLen);
 	rv = m_pFunc->C_InitPIN(hSession, (CK_UTF8CHAR_PTR) pPin, ulPinLen);
 	CPKCS11LIB_EPILOGUE;
 	return rv;
@@ -191,16 +193,14 @@ CK_RV CPKCS11Lib::C_InitPIN(
 
 CK_RV CPKCS11Lib::C_SetPIN(
 	CK_SESSION_HANDLE hSession,
-	char* pOldPin,
-	CK_ULONG ulOldLen,
-	char* pNewPin,
-	CK_ULONG ulNewLen)
+	vector<unsigned char> OldPin,
+	vector<unsigned char> NewPin)
 {
 	CPKCS11LIB_PROLOGUE(C_SetPIN);
-	if (NULL == pOldPin)
-		ulOldLen = 0;
-	if (NULL == pNewPin)
-		ulNewLen = 0;
+	CK_ULONG ulOldLen = 0;
+	CK_BYTE* pOldPin = Vector2Buffer(OldPin, ulOldLen);
+	CK_ULONG ulNewLen = 0;
+	CK_BYTE* pNewPin = Vector2Buffer(NewPin, ulNewLen);
 	rv = m_pFunc->C_SetPIN(hSession,
 		(CK_UTF8CHAR_PTR)pOldPin, ulOldLen,
 		(CK_UTF8CHAR_PTR)pNewPin, ulNewLen);
@@ -250,12 +250,11 @@ CK_RV CPKCS11Lib::C_GetSessionInfo(
 CK_RV CPKCS11Lib::C_Login(
 	CK_SESSION_HANDLE hSession,
 	CK_USER_TYPE userType,
-	char* pPin,
-	CK_ULONG ulPinLen)
+	vector<unsigned char> pin)
 {
 	CPKCS11LIB_PROLOGUE(C_Login);
-	if (NULL == pPin)
-		ulPinLen = 0;
+	CK_ULONG ulPinLen = 0;
+	CK_BYTE* pPin = Vector2Buffer(pin, ulPinLen);
 	rv = m_pFunc->C_Login(hSession, userType, (CK_UTF8CHAR_PTR)pPin, ulPinLen);
 	CPKCS11LIB_EPILOGUE;
 	return rv;
